## v0.2.5 (2023-06-09)

### Fix

- **client**: autoconnect on signup/signin

## v0.2.4 (2023-06-08)

### Fix

- **ws**: auto-connect to surreal when executing query

## v0.2.3 (2023-06-08)

### Fix

- fix DEFINE typo and remove quoting

## v0.2.2 (2023-06-08)

### Fix

- **config**: check if env_file exists

## v0.2.1 (2023-06-08)

### Fix

- **ws**: handle only URL for WebSockets

## v0.2.0 (2023-06-08)

### Feat

- **ws**: implement websockets handling and refactor use

## v0.1.5 (2023-04-19)

### Fix

- **where**: remove quotes from where statement

## v0.1.4 (2023-04-19)

### Fix

- **return**: remove quote from return statement

## v0.1.3 (2023-04-14)

### Fix

- **parser**: add int case

## v0.1.2 (2023-04-14)

### Fix

- **statements**: allow to use `return` and `where` statements with empty args

### Refactor

- **surrealdbv3**: refactor code to be used in pair with the latest version of surrealdb.py

## v0.1.0 (2022-11-07)
